==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/pkt/mark/grouping/NxmNxPktMark.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping;
import java.lang.Class;
import java.lang.Long;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxPktMarkGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-pkt-mark {
 *   leaf pkt-mark {
 *     type uint32;
 *   }
 *   leaf mask {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-pkt-mark-grouping/nxm-nx-pkt-mark</i>
 *
 * <p>To create instances of this class use {@link NxmNxPktMarkBuilder}.
 * @see NxmNxPktMarkBuilder
 *
 */
public interface NxmNxPktMark
    extends
    ChildOf<NxmNxPktMarkGrouping>,
    Augmentable<NxmNxPktMark>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-pkt-mark");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping.NxmNxPktMark> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping.NxmNxPktMark.class;
    }
    
    /**
     * @return <code>java.lang.Long</code> <code>pktMark</code>, or <code>null</code> if not present
     */
    @Nullable Long getPktMark();
    
    /**
     * @return <code>java.lang.Long</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Long getMask();

}

==> openflowplugin-extension-nicira-0.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/pkt/mark/grouping/NxmNxPktMark.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxPktMarkGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-pkt-mark {
 *   leaf pkt-mark {
 *     type uint32;
 *   }
 *   leaf mask {
 *     type uint32;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-pkt-mark-grouping/nxm-nx-pkt-mark</i>
 *
 * <p>To create instances of this class use {@link NxmNxPktMarkBuilder}.
 * @see NxmNxPktMarkBuilder
 *
 */
public interface NxmNxPktMark
    extends
    ChildOf<NxmNxPktMarkGrouping>,
    Augmentable<NxmNxPktMark>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-pkt-mark");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping.NxmNxPktMark> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.pkt.mark.grouping.NxmNxPktMark.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>pktMark</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getPktMark();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getMask();

}
